"""
    SXCU
    ~~~~

    Python API wrapper for sxcu.net.

    :copyright: Copyright 2020 by Naveen M K
    :license: Apache-2.0 , see LICENSE for details.

"""
from .__version__ import *  # noqa F401
from .sxcu import SXCU, OGProperties  # noqa F401
